.. include:: ../../README.rst


.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   installation.rst
   basic_usage.rst
   scripting.rst
   screens.rst
   running_scans.rst
   running_daq_scans.rst
   calibrating_delay_scans.rst


.. toctree::
   :maxdepth: 2
   :caption: Devices

   sndsystem.rst
   macromotor.rst
   tower.rst
   aerotech.rst
   attocube.rst
   diode.rst
   pneumatic.rst
   rtd.rst


.. toctree::
   :maxdepth: 2
   :caption: Plans

   alignment.rst
   calibration.rst
   scans.rst
   misc_plans.rst


.. toctree::
   :maxdepth: 2
   :caption: Miscellaneous

   bragg.rst
   utils.rst
   exceptions.rst
   api.rst


.. toctree::
   :hidden:
   :caption: Core SnD Packages

   pswalker <https://pswww.slac.stanford.edu/swdoc/releases/skywalker/pswalker/>
   pcds-devices <https://pswww.slac.stanford.edu/swdoc/releases/skywalker/pcds-devices/>
   pydm <https://slaclab.github.io/pydm/>

.. toctree::
   :hidden:
   :caption: Related Software

   bluesky <https://nsls-ii.github.io/bluesky>
   ophyd <https://nsls-ii.github.io/ophyd>


.. toctree::
   :hidden:
   :caption: GitHub Links

   SLAC <https://github.com/slaclab/>
   PCDS <https://github.com/pcdshub/>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
